# Copyright 2024- Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html)

from odoo import api, fields, models


class FinancialManager(models.Model):
    _name = "financial.manager"
    _description = "Mother (inheritance) of financial tools (loan, warranty and titles)"

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------
    intervention_type = fields.Selection(
        [("It must change", "For a Many 2 one field"), ("another", "one")],
        string="intervention",
    )
    payment_date = fields.Date()
    amount = fields.Monetary()
    duration_or_count = fields.Integer(
        help="The duration of a loan, or the number of pieces for a title"
    )
    rate = fields.Float()
    periodicity = fields.Selection([("6", "Semester"), ("12", "Year")])
    bank_account = fields.Char()
    currency_id = fields.Many2one(
        comodel_name="res.currency",
        string="Company Currency",
        compute="_compute_currency_id",
    )
    loan_id = fields.Many2one("loan.manager.loan")

    # FIXME to be implemented
    warrant_id = fields.Integer()

    # FIXME to be implemented
    title_id = fields.Integer()

    # ------------------------------------------------------
    # SQL Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Default methods
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------
    @api.model
    def _compute_currency_id(self):
        """
        Calcul la devise
        """
        for rec in self:
            rec.currency_id = self.env.user.company_id.currency_id.id

    # ------------------------------------------------------
    # Onchange / Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # CRUD methods (ORM overrides)
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Business methods
    # ------------------------------------------------------
